@@ -212,7 +212,7 @@ class RawToPrep(CompositeModule):
                             help="minimum voltage signal to track")
         parser.description = ARGS_DESC
 
-    async def setup(self, parsed_args, inputs, outputs, loop):
+    async def setup(self, parsed_args, inputs, outputs):
 
         # configure logger
         logger = logging.getLogger()
@@ -231,7 +231,6 @@ class RawToPrep(CompositeModule):
                                                        parsed_args.polar,
                                                        parsed_args.frequency)
         }
-
         out_iv = outputs['iv']
         # reconstructor --> sinefit
         r2s_iv = LocalPipe(out_iv.layout, name="r2s_iv", debug=False)
