@@ -44,7 +44,7 @@ class EthstreamCapture():
                 rows_processed += len(np_data)
                 if(nrows > 0 and rows_processed >= nrows):
                     self.stop_requested = True
-        except asyncio.streams.IncompleteReadError:
+        except asyncio.IncompleteReadError:
             if(not self.stop_requested):
                 logging.error("short read from ethstream, exiting")
         finally:
